@@ -1,3 +1,5 @@
+#  Copyright (c) 2022 Szymon Mikler
+
 import logging
 from typing import Any, List
 
@@ -255,7 +257,7 @@ class FunctionalModel(nn.Module):
             FMGraphNode object or a tuple of them.
         """
         super().__init__()
-        logging.info(f"Creating a Functional Model!")
+        logging.info("Creating a Functional Model...")
 
         if isinstance(inputs, FMGraphNode):
             inputs = (inputs,)
